==> smartgwt-12.0p.zip: com/smartgwt/logicalstructure/widgets/form/FilterBuilderLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.form;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class FilterBuilderLogicalStructure extends LayoutLogicalStructure {
    public String addButtonPrompt;
    public String allowEmpty;
    public AdvancedCriteria criteria;
    public DataSource dataSourceAsDataSource;
    public String dataSourceAsString;
    public DataSource fieldDataSource;
    public String fieldPickerTitle;
    public String fieldPickerWidthAsString;
    public String inlineAndNotTitle;
    public String inlineAndTitle;
    public String inlineOrTitle;
    public String lastClausePrompt;
    public String matchAllTitle;
    public String matchAnyTitle;
    public String matchNoneTitle;
    public String missingFieldPrompt;
    public String modeSwitcherAdvancedMessage;
    public String modeSwitcherFlattenWarningMessage;
    public String modeSwitcherSimpleMessage;
    public String operatorPickerTitle;
    public String operatorPickerWidthAsString;
    public String radioOperatorTitle;
    public String rangeSeparator;
    public String removeButtonPrompt;
    public String retainValuesAcrossFields;
    public String saveOnEnter;
    public String showAddButton;
    public String showFieldTitles;
    public String showModeSwitcher;
    public String showRemoveButton;
    public String showSelectionCheckbox;
    public String showSubClauseButton;
    public String sortFields;
    public String subClauseButtonPrompt;
    public String subClauseButtonTitle;
    public String topOperator;
    public String topOperatorAppearance;
    public String topOperatorItemWidthAsString;
    public String[] topOperatorOptions;
    public String topOperatorTitle;
    public String validateOnChange;
    public String valueItemWidthAsString;
}

==> smartgwt-13.0p.zip: com/smartgwt/logicalstructure/widgets/form/FilterBuilderLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.form;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class FilterBuilderLogicalStructure extends LayoutLogicalStructure {
    public String addButtonPrompt;
    public String[] allowedFields;
    public String allowEmpty;
    public AdvancedCriteria criteria;
    public DataSource dataSourceAsDataSource;
    public String dataSourceAsString;
    public DataSource fieldDataSource;
    public String fieldPickerTitle;
    public String fieldPickerWidthAsString;
    public String inlineAndNotTitle;
    public String inlineAndTitle;
    public String inlineOrTitle;
    public String lastClausePrompt;
    public String matchAllTitle;
    public String matchAnyTitle;
    public String matchNoneTitle;
    public String missingFieldPrompt;
    public String modeSwitcherAdvancedMessage;
    public String modeSwitcherFlattenWarningMessage;
    public String modeSwitcherSimpleMessage;
    public String operatorPickerTitle;
    public String operatorPickerWidthAsString;
    public String radioOperatorTitle;
    public String rangeSeparator;
    public String removeButtonPrompt;
    public String retainValuesAcrossFields;
    public String saveOnEnter;
    public String showAddButton;
    public String showFieldTitles;
    public String showHiddenFields;
    public String showLastRemoveButton;
    public String showModeSwitcher;
    public String showRemoveButton;
    public String showSelectionCheckbox;
    public String showSubClauseButton;
    public String sortFields;
    public String subClauseButtonPrompt;
    public String subClauseButtonTitle;
    public String topOperator;
    public String topOperatorAppearance;
    public String topOperatorItemWidthAsString;
    public String[] topOperatorOptions;
    public String topOperatorTitle;
    public String validateOnChange;
    public String valueItemWidthAsString;
}
